/**
 * @file
 * Vue-cart index.js.
 */

var apps = [];

const delimiters = ["${", "}"];
const comments = true;

window.dataLayer = window.dataLayer || [];
function gtag() { dataLayer.push(arguments); }

const store = Vuex.createStore({
  state: {
    cart: {
      items: {},
      quantity: 0,
      total: 0,
    },
    favorite: {
      total: 0,
    },
    color: 0,
  },
  mutations: {
    updateCart(state, cart) {
      state.cart = cart;
    },
    updateColor(state, color) {
      state.color = color;
    },
    updateFavorite(state, fav) {
      state.favorite = fav;
    },
  },
  actions: {
    sendDataLayers(state, carts) {
      let old_cart = carts.old_cart;
      let new_cart = carts.new_cart;
      if (old_cart.items && new_cart.items) {
        let old_cart_items = {};
        let new_cart_items = {};
        let items_old = Object.values(old_cart.items);
        items_old.forEach(element => {
          old_cart_items[element.vid] = element;
        });
        let items_new = Object.values(new_cart.items);
        items_new.forEach(element => {
          new_cart_items[element.vid] = element;
        });
        let new_cart_items_length = Object.keys(new_cart_items).length;
        let old_cart_items_length = Object.keys(old_cart_items).length;
        if (new_cart_items_length == old_cart_items_length) {
          for (const [key, element] of Object.entries(new_cart_items)) {
            let old_quantity = +old_cart_items[key].quantity;
            if (old_quantity != +element.quantity) {
              let change_quantity = element.quantity - old_quantity;
              if (change_quantity > 0) {
                console.log(change_quantity);
                dataLayerEvent('add', element, Math.abs(change_quantity));
              }
              if (change_quantity < 0) {
                console.log(change_quantity);
                dataLayerEvent('remove', element, Math.abs(change_quantity));
              }
            }
          }
        } else if (new_cart_items_length > old_cart_items_length) {
          for (const [key, element] of Object.entries(new_cart_items)) {
            if (old_cart_items[key] == undefined) {
              console.log(element.quantity);
              dataLayerEvent('add', element, element.quantity);
            }
          }
        } else if (new_cart_items_length < old_cart_items_length) {
          for (const [key, element] of Object.entries(old_cart_items)) {
            if (new_cart_items[key] == undefined) {
              console.log(element.quantity);
              dataLayerEvent('remove', element, element.quantity);
            }
          }
        }
      }
    },
    refreshStock(state) {
      let request_data = {};
      let items = state.state.cart.items;
      if (typeof (items[0]) != "undefined" && items[0] !== null && items[0].checkstore) {
        items.forEach(item => {
          request_data[item.id] = {};
          request_data[item.id]['vid'] = item.vid;
          request_data[item.id]['quantity'] = item.quantity;
        });
        axios.post("/cart/refresh-stock", { items: request_data }).then((response) => {
          let data = response.data;
          data.forEach(item_stock_data => {
            let index = items.findIndex((element) => element['vid'] == item_stock_data.vid);
            state.state.cart.items[index].stock = item_stock_data['stock'];
            this.commit('updateCart', state.state.cart);
          });
        });
      }
    },
    setItemQuantity(state, data) {
      axios.post("/cart/set-product-quantity", {
        item_id: data.item_id,
        quantity: data.quantity,
      }).then(
        (response) => {
          this.commit('updateCart', response.data);
        },
      );
    },
    setItemNote(item) {
      axios
        .post("/cart/set-item-note", {
          itemId: item.id,
          note: item.data_note,
        }).then(
          (response) => {
            this.commit("updateCart", response.data);
          },
        );
    },
    removeItem(state, data) {
      axios.post("/cart/remove-cart-item", { item_id: data.item_id });
    },
  }
});
