<?php

namespace Drupal\syncart\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\state_machine\Event\WorkflowTransitionEvent;
use Drupal\Core\Entity\EntityTypeManager;

/**
 * Class OrderCompleteSubscriber.
 *
 * @package Drupal\syncart
 */
class OrderCompleteSubscriber implements EventSubscriberInterface {

  /**
   * Drupal\Core\Entity\EntityTypeManager definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManager
   */
  protected $entityTypeManager;

  /**
   * Constructor.
   */
  public function __construct(EntityTypeManager $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events['commerce_order.place.post_transition'] = ['orderCompleteHandler'];
    return $events;
  }

  /**
   * Send e-mail.
   *
   * @param \Drupal\state_machine\Event\WorkflowTransitionEvent $event
   *   The transition event.
   */
  public function orderCompleteHandler(WorkflowTransitionEvent $event) {
    /** @var \Drupal\commerce_order\Entity\OrderInterface $order */
    $order = $event->getEntity();
    if (\Drupal::config('syncart.settings')->get('check_store')) {
      $order_item_storage = \Drupal::entityTypeManager()->getStorage('commerce_order_item');
      foreach ($order->order_items->getValue() as $item_data) {
        $item = $order_item_storage->load($item_data['target_id']);
        $quantity = (float) $item->quantity->value;
        $variation = $item->purchased_entity->entity;
        $current_stock = (float) $variation->field_stock->value;
        $variation->set('field_stock', $current_stock - $quantity);
        $variation->save();
      }
    }
    \Drupal::service('syncart.cart')->sendReceipt($order);
  }

}
